<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\Auth;
use Log;

class CustomerOrderCancelController extends Controller {

    public function __construct() {
        
    }

    public function home() {

        return view('welcome');
    }

    /**
     * Set endpoint request details
     */
    public function getEndPointRequestDetails(Request $request) {

        $errorMessage = '';
        $returnData = [];
        $shop = Auth::user();
        $returnData['endpointRequest'] = '';
        $returnData['errorMessage'] = '';
        $orderId = !empty($request->get('id')) ? $request->get('id') : '';

        if (empty($orderId)) {

            $errorMessage = "Failed to get the orderId from Shopify";
            $error = "Failed to get the orderId from the URL";
            Log::channel('OrderCancelLog')->info($error);
            $returnData['errorMessage'] = $errorMessage;
            return view('order',compact('returnData'));
        }

        $orderDetails = $shop->api()->rest('GET',
        '/admin/orders/'.$orderId.'.json');

        $customerOrderDetails = isset($orderDetails['body']['order']) ? 
        $orderDetails['body']['container']['order'] : '';

        if (empty($customerOrderDetails) || !isset($customerOrderDetails)) {

            $error = "Failed to get the order details from Shopify, OrderId:".$orderId;
            Log::channel('OrderCancelLog')->info($error);
            $errorMessage = "Failed to get the order details from Shopify";
            $returnData['errorMessage'] = $errorMessage;
            return view('order',compact('returnData'));
        }

        $orderCustomerId = !empty($customerOrderDetails['customer']['id']) ? 
        trim($customerOrderDetails['customer']['id']) : '';
        $orderTags = !empty($customerOrderDetails['tags']) ? 
        trim($customerOrderDetails['tags']) : '';

        if (empty($orderCustomerId) || !isset($orderCustomerId)) {

            $error = "Failed to get the customer details of the order, OrderId:".$orderId;
            Log::channel('OrderCancelLog')->info($error);
            $errorMessage = "Failed to get the customer details from Shopify";
            $returnData['errorMessage'] = $errorMessage;
            return view('order',compact('returnData'));
        }

        $orderCreationToolCreatedStatus = $this->checkOrderTagWithCustomOrderToolCreated($orderTags);

        $customerMetafields = $shop->api()->rest('GET',
        '/admin/customers/'.$orderCustomerId.'/metafields.json');

        $customerMetafieldDetails = isset($customerMetafields['body']['metafields']) ?
        $customerMetafields['body']['container']['metafields'] : '';

        if (empty($customerMetafieldDetails) || !isset($customerMetafieldDetails)) {

            $error = "Failed to get the customer metafield details from Shopify(CustomerId:".$orderCustomerId.", 
            OrderId:".$orderId.")";
            Log::channel('OrderCancelLog')->info($error);
            $errorMessage = "Failed to get the customer hash value from Shopify";
            $returnData['errorMessage'] = $errorMessage;
            return view('order',compact('returnData'));
        }

        $metaFieldKey = '';
        $customerHash = '';
        foreach ($customerMetafieldDetails as $metaKey => $metaValue) {

            $metaFieldKey = !empty($metaValue['key']) ? trim($metaValue['key']) : '';
            if ($metaFieldKey == 'customer_string') {

                $customerHash = $metaValue['value'];
            }
        }

        if ((empty($customerHash) || !isset($customerHash)) && $orderCreationToolCreatedStatus == "false") {

            $error = "Failed to get the customer hash value from Shopify(CustomerId:".$orderCustomerId.", 
            OrderId:".$orderId.")";
            Log::channel('OrderCancelLog')->info($error);
            $errorMessage = "Not found the order details in recharge";
            $returnData['errorMessage'] = $errorMessage;
            return view('order',compact('returnData'));
        }

        $endpointRequestData = [];
        $endpointRequestData = [
            "hash" => $customerHash,
            "orderId" => $orderId,
            "allFutureOrders" => "0",
            "comments" => "Please honor this cancellation request from Customer Service.",
            "orderCreationToolStatus" => $orderCreationToolCreatedStatus
        ];
        $returnData['endpointRequest'] = $endpointRequestData;

        return view('order',compact('returnData'));
    }

    /**
     * Check Shopify order tags
     */
    public function checkOrderTagWithCustomOrderToolCreated($orderTags) {

        if (!empty($orderTags)) {

            $explodeTags = explode(",", $orderTags);
            $explodeTags = array_map('trim', $explodeTags);
            $explodeTags = array_map('strtolower', $explodeTags);
            if (in_array("custom-order-tool-created", $explodeTags)) {
                return "true";
            }
            return "false";
        }
        return "false";
    }
}
